@@ -24,7 +24,6 @@ import streamlit.components.v1 as components
 
 from . import SessionState
 from .config import MediaStreamConstraints, RTCConfiguration
-from .eventloop import get_server_event_loop
 from .webrtc import (
     AudioProcessorBase,
     AudioProcessorFactory,
@@ -393,9 +392,7 @@ def webrtc_streamer(
             'Create a new worker (key="%s").',
             key,
         )
-        loop = get_server_event_loop()
         webrtc_worker = WebRtcWorker(
-            loop=loop,
             mode=mode,
             player_factory=player_factory,
             in_recorder_factory=in_recorder_factory,
